Name: icingadb-redis
Version: 7.0.12
Release: 1%{?dist}
Summary: A persistent key-value database

License: BSD-3-Clause AND BSD-2-Clause AND MIT
URL: https://redis.io
Source0: icingadb-redis-7.0.12.tgz
Source1: icingadb-redis-rpm.tgz

BuildRequires: make

BuildRequires: gcc

BuildRequires: pkgconfig(libsystemd)
BuildRequires: systemd-devel
BuildRequires: systemd-rpm-macros
BuildRequires: openssl-devel

Obsoletes: redis-trib < 5

Requires: /bin/awk
Requires: logrotate

Requires(pre): shadow-utils

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Provides: bundled(hiredis) = 0.14.0

Provides: bundled(jemalloc) = 5.2.1

Provides: bundled(lua-libs) = 5.1.5

Provides: bundled(linenoise) = 1.0
Provides: bundled(lzf)

Provides: bundled(hdr_histogram) = 0.11.0

Provides: redis(modules_abi)%{?_isa} = 1

Conflicts: icinga-redis

%description
Redis is an advanced key-value store. It is often referred to as a data
structure server since keys can contain strings, hashes, lists, sets and
sorted sets.

You can run atomic operations on these types, like appending to a string;
incrementing the value in a hash; pushing to a list; computing set
intersection, union and difference; or getting the member with highest
ranking in a sorted set.

In order to achieve its outstanding performance, Redis works with an
in-memory dataset. Depending on your use case, you can persist it either
by dumping the dataset to disk every once in a while, or by appending
each command to a log.

Redis also supports trivial-to-setup master-slave replication, with very
fast non-blocking first synchronization, auto-reconnection on net split
and so forth.

Other features include Transactions, Pub/Sub, Lua scripting, Keys with a
limited time-to-live, and configuration settings to make Redis behave like
a cache.

You can use Redis from most programming languages also.

%package devel
Summary: Development header for Redis module development

Provides: redis-static = 7.0.12-1%{?dist}

%description devel
Header file required for building loadable Redis modules. Detailed
API documentation is available in the redis-doc package.

%prep
%autosetup
install -d sources
cd sources
tar -xvzf %_topdir/SOURCES/icingadb-redis-rpm.tgz
cd -
for patch in sources/*.patch; do
patch -p1 -s < "$patch"
done

mv deps/lua/COPYRIGHT COPYRIGHT-lua
mv deps/jemalloc/COPYING COPYING-jemalloc
mv deps/hiredis/COPYING COPYING-hiredis
mv deps/hdr_histogram/LICENSE.txt LICENSE-hdrhistogram
mv deps/hdr_histogram/COPYING.txt COPYING-hdrhistogram

sed -i -e 's|^logfile .*$|logfile /var/log/icingadb-redis/redis.log|g' redis.conf
sed -i -e 's|^logfile .*$|logfile /var/log/icingadb-redis/sentinel.log|g' sentinel.conf
sed -i -e 's|^dir .*$|dir /var/lib/icingadb-redis|g' redis.conf

sed -i -e 's|^port .*$|port 6380|'g redis.conf
sed -i -e 's|^port .*$|port 26380|'g sentinel.conf

sed -i -e 's|^pidfile .*$|pidfile /var/run/icingadb-redis/redis.pid|g' redis.conf
sed -i -e 's|^pidfile .*$|pidfile /var/run/icingadb-redis/redis-sentinel.pid|g' sentinel.conf

api=`sed -n -e 's/#define REDISMODULE_APIVER_[0-9][0-9]* //p' src/redismodule.h`
if test "$api" != "1"; then
: Error: Upstream API version is now ${api}, expecting %{redis_modules_abi}.
: Update the redis_modules_abi macro, the rpmmacros file, and rebuild.
exit 1
fi

%global make_flags	DEBUG="" V="echo" LDFLAGS="%{?__global_ldflags}" CFLAGS+="%{optflags} -fPIC" INSTALL="install -p" PREFIX=%{buildroot}%{_prefix} BUILD_WITH_SYSTEMD=yes BUILD_TLS=yes

%build
%make_build %{make_flags} all

%install
make %{make_flags} install

install -d %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/var/lib/icingadb-redis
install -d %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/var/log/icingadb-redis
install -d %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/var/run/icingadb-redis
install -d %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/lib64/icingadb-redis/modules

install -pDm644 sources/redis.logrotate %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/logrotate.d/icingadb-redis

install -pd %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/icingadb-redis
install -pDm640 redis.conf %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/icingadb-redis/icingadb-redis.conf
install -pDm640 sentinel.conf %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/icingadb-redis/icingadb-sentinel.conf

mkdir -p %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}%{_unitdir}
install -pm644 sources/redis.service %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}%{_unitdir}/icingadb-redis.service
install -pm644 sources/redis-sentinel.service %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}%{_unitdir}/icingadb-redis-sentinel.service

install -p -D -m 644 sources/redis-limit-systemd %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/systemd/system/icingadb-redis.service.d/limit.conf
install -p -D -m 644 sources/redis-limit-systemd %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/etc/systemd/system/icingadb-redis-sentinel.service.d/limit.conf

for bin in $(cd %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin; ls redis*); do
[ -z icingadb- ] || mv %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin/${bin} %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin/icingadb-${bin}
chmod 755 %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin/icingadb-${bin}
done

if [ -n icingadb- ]; then
ln -svf icingadb-redis-server %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin/icingadb-redis-check-aof
ln -svf icingadb-redis-server %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/bin/icingadb-redis-check-rdb
fi

install -pDm755 sources/redis-shutdown %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/libexec/icingadb-redis-shutdown

install -pDm644 src/redismodule.h %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/include/icingadb-redismodule.h

man=$(dirname %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/share/man)
for page in man/man?/*; do
dir=$(dirname $page)
file=$(basename $page)
install -Dpm644 $page $man/$dir/icingadb-$file
done
ln -s redis-server.1 %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/share/man/man1/icingadb-redis-sentinel.1
ln -s redis.conf.5 %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/share/man/man5/icingadb-redis-sentinel.conf.5

mkdir -p %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/lib/rpm/macros.d
install -pDm644 sources/macros.redis %_topdir/BUILDROOT/icingadb-redis-7.0.12-1%{?dist}.%{_arch}/usr/lib/rpm/macros.d/macros.icingadb-redis

%check
: Test disabled, missing '--with tests' option.

%pre
getent group icingadb-redis &> /dev/null || \
groupadd -r icingadb-redis &> /dev/null
getent passwd icingadb-redis &> /dev/null || \
useradd -r -g icingadb-redis -d /var/lib/icingadb-redis -s /sbin/nologin \
-c 'Redis Database Server' icingadb-redis &> /dev/null
exit 0

%post
if [ -f /etc/icingadb-redis.conf -a ! -L /etc/icingadb-redis.conf ]; then
if [ -f /etc/icingadb-redis/icingadb-redis.conf.rpmnew ]; then
rm /etc/icingadb-redis/icingadb-redis.conf.rpmnew
fi
if [ -f /etc/icingadb-redis/icingadb-redis.conf ]; then
mv /etc/icingadb-redis/icingadb-redis.conf /etc/icingadb-redis/icingadb-redis.conf.rpmnew
fi
mv /etc/icingadb-redis.conf /etc/icingadb-redis/icingadb-redis.conf
echo -e "\nWarning: icingadb-redis configuration is now in /etc/icingadb-redis directory\n"
fi
if [ -f /etc/icingadb-redis-sentinel.conf -a ! -L /etc/icingadb-redis-sentinel.conf ]; then
if [ -f /etc/icingadb-redis/icingadb-sentinel.conf.rpmnew ]; then
rm /etc/icingadb-redis/icingadb-sentinel.conf.rpmnew
fi
if [ -f /etc/icingadb-redis/icingadb-sentinel.conf ]; then
mv /etc/icingadb-redis/icingadb-sentinel.conf /etc/icingadb-redis/icingadb-sentinel.conf.rpmnew
fi
mv /etc/icingadb-redis-sentinel.conf /etc/icingadb-redis/icingadb-sentinel.conf
fi
%systemd_post icingadb-redis.service
%systemd_post icingadb-redis-sentinel.service

%preun
%systemd_preun icingadb-redis.service
%systemd_preun icingadb-redis-sentinel.service

%postun
%systemd_postun_with_restart icingadb-redis.service
%systemd_postun_with_restart icingadb-redis-sentinel.service

%files
%license COPYING
%license COPYRIGHT-lua
%license COPYING-jemalloc
%license COPYING-hiredis
%license LICENSE-hdrhistogram
%license COPYING-hdrhistogram
%config(noreplace) /etc/logrotate.d/icingadb-redis
%attr(0750, icingadb-redis, root) %dir /etc/icingadb-redis
%attr(0640, icingadb-redis, root) %config(noreplace) /etc/icingadb-redis/icingadb-redis.conf
%attr(0640, icingadb-redis, root) %config(noreplace) /etc/icingadb-redis/icingadb-sentinel.conf
%dir %attr(0750, icingadb-redis, icingadb-redis) /usr/lib64/icingadb-redis
%dir %attr(0750, icingadb-redis, icingadb-redis) /usr/lib64/icingadb-redis/modules
%dir %attr(0750, icingadb-redis, icingadb-redis) /var/lib/icingadb-redis
%dir %attr(0750, icingadb-redis, icingadb-redis) /var/log/icingadb-redis
%exclude /usr/lib/rpm/macros.d
%exclude /usr/include
/usr/bin/icingadb-redis-*
/usr/libexec/icingadb-redis-*
/usr/share/man/man1/icingadb-redis*
/usr/share/man/man5/icingadb-redis*
%{_unitdir}/icingadb-redis.service
%{_unitdir}/icingadb-redis-sentinel.service
%dir /etc/systemd/system/icingadb-redis.service.d
%config(noreplace) /etc/systemd/system/icingadb-redis.service.d/limit.conf
%dir /etc/systemd/system/icingadb-redis-sentinel.service.d
%config(noreplace) /etc/systemd/system/icingadb-redis-sentinel.service.d/limit.conf
%dir %attr(0755, icingadb-redis, icingadb-redis) %ghost /var/run/icingadb-redis

%files devel
%license COPYING
/usr/include/icingadb-redismodule.h
/usr/lib/rpm/macros.d/*

%changelog
* Wed Sep 06 2023 Icinga GmbH <info@icinga.com> - 7.0.12-1
- Version 7.0.12-1

* Tue Mar 21 2023 Remi Collet <remi@remirepo.net> - 7.0.10-1
- Upstream 7.0.10 release.

* Wed Feb 1 2023 Remi Collet <remi@remirepo.net> - 7.0.9-1
- Upstream 7.0.9 release.

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Jan 17 2023 Remi Collet <remi@remirepo.net> - 7.0.8-1
- Upstream 7.0.8 release.

* Fri Dec 16 2022 Remi Collet <remi@remirepo.net> - 7.0.7-2
- Upstream 7.0.7 release.
- refresh documentation

* Tue Dec 13 2022 Remi Collet <remi@remirepo.net> - 7.0.6-1
- Upstream 7.0.6 release.

* Mon Dec 5 2022 Florian Weimer <fweimer@redhat.com> - 7.0.5-2
- Port makefile to C99 mode

* Fri Oct 14 2022 Henrik Triem <henrik.triem@icinga.com> - 7.0.5-1
- Update to 7.0.5-1

* Thu Sep 22 2022 Remi Collet <remi@remirepo.net> - 7.0.5-1
- Upstream 7.0.5 security release.

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 18 2022 Remi Collet <remi@remirepo.net> - 7.0.4-1
- Upstream 7.0.4 release.

* Tue Jul 12 2022 Remi Collet <remi@remirepo.net> - 7.0.3-1
- Upstream 7.0.3 release.

* Mon Jun 20 2022 Henrik Triem <henrik.triem@icinga.com> - 7.0.2-1
- Update to 7.0.2-1

* Mon Jun 13 2022 Remi Collet <remi@remirepo.net> - 7.0.2-1
- Upstream 7.0.2 release.

* Wed Jun 8 2022 Remi Collet <remi@remirepo.net> - 7.0.1-1
- Upstream 7.0.1 release.

* Mon May 23 2022 Henrik Triem <henrik.triem@icinga.com> - 7.0.0-1
- Update to 7.0.0-1

* Fri May 20 2022 Henrik Triem <henrik.triem@icinga.com> - 6.2.7-1
- Update to 6.2.7-1

* Thu Apr 28 2022 Remi Collet <remi@remirepo.net> - 7.0.0-1
- Upstream 7.0.0 release.

* Thu Apr 28 2022 Remi Collet <remi@remirepo.net> - 6.2.7-1
- Upstream 6.2.7 release.

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Nov 12 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.6-3
- Redis-shutdown: Look for icingadb-redis

* Wed Nov 3 2021 Remi Collet <remi@remirepo.net> - 6.2.6-2
- use proper license in dec/devel sub-packages

* Mon Oct 4 2021 Remi Collet <remi@remirepo.net> - 6.2.6-1
- Upstream 6.2.6 release.

* Tue Sep 14 2021 Sahana Prasad <sahana@redhat.com> - 6.2.5-2
- Rebuilt with OpenSSL 3.0.0

* Thu Jul 29 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.6-2
- Add icinga-redis as conflicting package

* Thu Jul 29 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.6-1
- Update to 6.2.6-1

* Thu Jul 29 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.5-1
- Update to 6.2.5-1

* Thu Jul 22 2021 Nathan Scott <nathans@redhat.com> - 6.2.5-1
- Upstream 6.2.5 release (RHBZ #1984631).
- Fix CVE-2021-32761: 32-bit systems BITFIELD command integer overflow.

* Wed Jun 30 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.4-1
- Update to 6.2.4-1

* Wed Jun 2 2021 Remi Collet <remi@remirepo.net> - 6.2.4-1
- Upstream 6.2.4 release.

* Tue May 4 2021 Remi Collet <remi@remirepo.net> - 6.2.3-1
- Upstream 6.2.3 release

* Tue Apr 20 2021 Remi Collet <remi@remirepo.net> - 6.2.2-1
- Upstream 6.2.2 release

* Thu Apr 01 2021 Nathan Scott <nathans@redhat.com> - 6.2.1-1
- Upstream 6.2.1 release
- Merged make-macros spec change from Tom Stellard

* Tue Mar 02 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 6.2.0-2
- Rebuilt for updated systemd-rpm-macros
See https://pagure.io/fesco/issue/2583.

* Mon Mar 01 2021 Nathan Scott <nathans@redhat.com> - 6.2.0-1
- Upstream 6.2.0 release (RHBZ #1915463).
- drop patch merged upstream.

* Wed Feb 24 2021 Nathan Scott <nathans@redhat.com> - 6.0.11-1
- Upstream 6.0.11 release.

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jan 13 2021 Remi Collet <remi@remirepo.net> - 6.0.10-1
- Upstream 6.0.10 release.

* Tue Nov 24 2020 Remi Collet <remi@remirepo.net> - 6.0.9-3
- fix check for regular file, not symlink

* Mon Nov 23 2020 Remi Collet <remi@remirepo.net> - 6.0.9-2
- move configuration in /etc/redis per upstream recommendation
see https://github.com/redis/redis/issues/8051

* Tue Oct 27 2020 Remi Collet <remi@remirepo.net> - 6.0.9-1
- Upstream 6.0.9 release.

* Tue Oct 20 2020 Remi Collet <remi@remirepo.net> - 6.0.8-2
- add missing LICENSE files in main package

* Thu Sep 10 2020 Remi Collet <remi@remirepo.net> - 6.0.8-1
- Upstream 6.0.8 release.

* Tue Sep 1 2020 Remi Collet <remi@remirepo.net> - 6.0.7-1
- Upstream 6.0.7 release.
- drop patch merged upstream

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 21 2020 Remi Collet <rcollet@redhat.com> - 6.0.6-1
- Upstream 6.0.6 release.
- drop patch merged upstream
- open https://github.com/redis/redis/pull/7543 fix deprecated tail syntax

* Wed Jun 10 2020 Nathan Scott <nathans@redhat.com> - 6.0.5-1
- Upstream 6.0.5 release.

* Thu May 28 2020 Remi Collet <remi@remirepo.net> - 6.0.4-3
- Add comment for TimeoutStartSec and TimeoutStopSec in limit.conf
- Fix missing notification to systemd for sentinel
patch from https://github.com/redis/redis/pull/7168
- Upstream 6.0.4 release.

* Mon May 18 2020 Nathan Scott <nathans@redhat.com> - 6.0.3-1
- Upstream 6.0.3 release.

* Wed May 6 2020 Remi Collet <rcollet@redhat.com> - 6.0.1-1
- Upstream 6.0.1 release.

* Fri May 01 2020 Nathan Scott <nathans@redhat.com> - 6.0.0-1
- Upstream 6.0.0 release.

* Fri Mar 13 2020 Nathan Scott <nathans@redhat.com> - 5.0.8-1
- Upstream 5.0.8 release.

* Wed Feb 12 2020 Nathan Scott <nathans@redhat.com> - 5.0.7-3
- Patch extern SDS_NOINIT definition for gcc 10 (RHBZ #1799969)

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Nov 19 2019 Carl George <carl@george.computer> - 5.0.7-1
- Latest upstream

* Thu Sep 26 2019 Nathan Scott <nathans@redhat.com> - 5.0.6-1
- Upstream 5.0.6 release and redis-doc updates.

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Jul 15 2019 Nathan Scott <nathans@redhat.com> - 5.0.5-2
- Use the (modified) bundled jemalloc for defrag (RHBZ #1725852)

* Thu May 16 2019 Nathan Scott <nathans@redhat.com> - 5.0.5-1
- Upstream 5.0.5 release and redis-doc updates.

* Sat May 11 2019 Nathan Scott <nathans@redhat.com> - 5.0.4-2
- Obsolete redis-trib - functionality now in redis-cli(1)
- Remove old chkconfig support, all systemd platforms now

* Tue Mar 19 2019 Nathan Scott <nathans@redhat.com> - 5.0.4-1
- Upstream 5.0.4 release and redis-doc updates.
- Fix sentinel.conf logfile line addition.

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Dec 13 2018 Nathan Scott <nathans@redhat.com> - 5.0.3-1
- Upstream 5.0.3 release and redis-doc updates.

* Fri Nov 23 2018 Nathan Scott <nathans@redhat.com> - 5.0.2-1
- Upstream 5.0.2 release and redis-doc updates.

* Thu Nov 08 2018 Nathan Scott <nathans@redhat.com> - 5.0.1-1
- Upstream 5.0.1 release.

* Thu Oct 18 2018 Nathan Scott <nathans@redhat.com> - 5.0.0-1
- Update systemd service files for network-online requirement
- Upstream 5.0.0 release.

* Thu Aug 09 2018 Nathan Scott <nathans@redhat.com> - 4.0.11-1
- Drop the pandoc build dependency, install only markdown.
- Upstream 4.0.11 release.

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 25 2018 Remi Collet <rcollet@redhat.com> - 4.0.10-2
- fix License (BSD and MIT)
- add bundled libraries licences
- add information about bundled lzf

* Thu Jun 14 2018 Nathan Scott <nathans@redhat.com> - 4.0.10-1
- Upstream 4.0.10 release.

* Tue Mar 27 2018 Nathan Scott <nathans@redhat.com> - 4.0.9-1
- Upstream 4.0.9 release.

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 4.0.8-2
- Escape macros in %changelog
* Wed Feb 7 2018 Nathan Scott <nathans@redhat.com> - 4.0.8-1
- Upstream 4.0.8 release.

* Wed Jan 31 2018 Nathan Scott <nathans@redhat.com> - 4.0.7-1
- Upstream 4.0.7 release.

* Thu Dec 7 2017 Nathan Scott <nathans@redhat.com> - 4.0.6-1
- Upstream 4.0.6 release.

* Fri Dec 1 2017 Remi Collet <remi@remirepo.net> - 4.0.5-1
- Redis 4.0.5 - Released Thu Dec 1 16:03:32 CET 2017
- Upgrade urgency CRITICAL: Redis 4.0.4 fix for PSYNC2 was broken,
causing the slave to crash when receiving an RDB file from the
master that contained a duplicated Lua script.

* Fri Dec 01 2017 Nathan Scott <nathans@redhat.com> - 4.0.4-1
- Upstream 4.0.4 release.
- Update to current upstream redis-doc also.
- Fix man page issues (RHBZ #1513594 and RHBZ #1515417).

* Thu Nov 30 2017 Remi Collet <remi@remirepo.net> - 4.0.3-1
- Redis 4.0.3
- fix ownership of /usr/share/doc/redis
- use make_flags for test to avoid rebuild and failure
- fix rpm macro location on EL-6
- add /var/run/redis on EL-6
- add spec file license header
- drop duplicated documentation from main package
- keep man in main page

* Fri Nov 17 2017 Nathan Scott <nathans@redhat.com> - 4.0.2-2
- Install the base modules directories, owned by the main package.

* Tue Oct 31 2017 Nathan Scott <nathans@redhat.com> - 4.0.2-1
- Upstream 4.0.2 release. (RHBZ #1389592)
- Add redis-devel for loadable module development.
- Add redis-doc for man pages and detailed documentation.
- Provide redis-check-aof as a symlink to redis-server also now.

* Tue Sep 26 2017 Nathan Scott <nathans@redhat.com> - 3.2.11-1
- Upstream 3.2.11 bug-fix-only release
- Switch to using Type=notify for Redis systemd services (RHBZ #1172841)
- Add Provides:bundled hiredis, linenoise, lua-libs clauses (RHBZ #788500)

* Mon Aug 14 2017 Nathan Scott <nathans@redhat.com> - 3.2.10-2
- Add redis-trib based on patch from Sebastian Saletnik. (RHBZ #1215654)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Mon Jul 31 2017 Nathan Scott <nathans@redhat.com> - 3.2.10-1
- Upstream 3.2.10 release
- Ensure both the redis and redis-sentinel service files set correct perms
- Dropped systemd tmpfiles source, handled directly in systemd service files

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 29 2017 Nathan Scott <nathans@redhat.com> - 3.2.9-1
- Upstream 3.2.9
- Add RuntimeDirectory=redis to systemd unit file (RHBZ #1454700)
- Mark rundir as %ghost since it may disappear (tmpfs - #1454700)
- Fix a shutdown failure with Unix domain sockets (RHBZ #1444988)

* Mon Feb 20 2017 Haïkel Guémar <hguemar@fedoraproject.org> - 3.2.8-1
- Upstream 3.2.8
- bugfix for #3796 (MIGRATE could cause server crash after socket error)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Feb 4 2017 Haïkel Guémar <hguemar@fedoraproject.org> - 3.2.7-1
- Upstream 3.2.7 (important security fix)

* Sat Nov 05 2016 Alan Pevec <apevec AT redhat.com> - 3.2.4-2
- Install tmpfiles and /run/redis for legacy configurations

* Mon Sep 26 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 3.2.4-1
- Upstream 3.2.4
- Fix buffer overlow (TALOS-2016-0206)

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 3.2.3-2
- add missing man pages #1374577
using patch from https://github.com/redis/redis/pull/3491
- data and configuration should not be publicly readable #1374700
- remove /var/run/redis with systemd #1374728
- provide redis-check-rdb as a symlink to redis-server #1374736
using patch from https://github.com/redis/redis/pull/3494
- move redis-shutdown to libexec

* Thu Aug 4 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 3.2.3-1
- Upstream 3.2.3
- Security fix for CVE-2013-7458 (redis-cli history world readable)
- RHBZ#1363670 RHBZ#1363671

* Mon Feb 8 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.6-3
- Fix redis-shutdown to handle password-protected instances shutdown

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Dec 19 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.6-1
- Upstream 3.0.6 (RHBZ#1272281)

* Fri Oct 16 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.5-1
- Upstream 3.0.5
- Fix slave/master replication hanging forever in certain case

* Mon Sep 07 2015 Christopher Meng <rpm@cicku.me> - 3.0.4-1
- Update to 3.0.4

* Sun Aug 30 2015 Christopher Meng <rpm@cicku.me> - 3.0.3-2
- Rebuilt for jemalloc 4.0.0

* Tue Jul 21 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.3-1
- Upstream 3.0.3

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 04 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.2-1
- Upstream 3.0.2 (RHBZ #1228245)
- Fix Lua sandbox escape and arbitrary code execution (RHBZ #1228331)

* Sat May 09 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.1-1
- Upstream 3.0.1 (RHBZ #1208322)

* Tue Apr 14 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-2
- rotate /var/log/redis/sentinel.log

* Thu Apr 2 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 3.0.0-1
- Upstream 3.0.0 (RHBZ #1208322)

* Thu Mar 26 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.19-2
- Fix redis-shutdown on multiple NIC setup (RHBZ #1201237)

* Fri Feb 27 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.19-1
- Upstream 2.8.19 (RHBZ #1175232)
- Fix permissions for tmpfiles (RHBZ #1182913)
- Add limits config files
- Spec cleanups

* Fri Dec 05 2014 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.18-1
- Upstream 2.8.18
- Rebased patches

* Sat Sep 20 2014 Remi Collet <remi@fedoraproject.org> - 2.8.17-1
- Upstream 2.8.17
- fix redis-sentinel service unit file for systemd
- fix redis-shutdown for sentinel
- also use redis-shutdown in init scripts

* Wed Sep 17 2014 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.15-2
- Minor fix to redis-shutdown (from Remi Collet)

* Sat Sep 13 2014 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.15-1
- Upstream 2.8.15 (critical bugfix for sentinel)
- Fix to sentinel systemd service and configuration (thanks Remi)
- Refresh patch management

* Thu Sep 11 2014 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.14-2
- Cleanup spec
- Fix shutdown for redis-{server,sentinel}
- Backport fixes from Remi Collet repository (ie: sentinel working)

* Thu Sep 11 2014 Haïkel Guémar <hguemar@fedoraproject.org> - 2.8.14-1
- Upstream 2.8.14 (RHBZ #1136287)
- Bugfix for lua scripting users (server crash)
- Refresh patches
- backport spec from EPEL7 (thanks Warren)

* Wed Jul 16 2014 Christopher Meng <rpm@cicku.me> - 2.8.13-1
- Update to 2.8.13

* Tue Jun 24 2014 Christopher Meng <rpm@cicku.me> - 2.8.12-1
- Update to 2.8.12

* Wed Jun 18 2014 Christopher Meng <rpm@cicku.me> - 2.8.11-1
- Update to 2.8.11

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Sep 06 2013 Fabian Deutsch <fabian.deutsch@gmx.de> - 2.6.16-1
- Update to 2.6.16
- Fix rhbz#973151
- Fix rhbz#656683
- Fix rhbz#977357 (Jan Vcelak <jvcelak@fedoraproject.org>)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 23 2013 Peter Robinson <pbrobinson@fedoraproject.org> 2.6.13-4
- ARM has gperftools

* Wed Jun 19 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 2.6.13-3
- Modify jemalloc patch for s390 compatibility (Thanks sharkcz)

* Fri Jun 07 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 2.6.13-2
- Unbundle jemalloc

* Fri Jun 07 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 2.6.13-1
- Add compile PIE flag (rhbz#955459)
- Update to redis 2.6.13 (rhbz#820919)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec 27 2012 Silas Sewell <silas@sewell.org> - 2.6.7-1
- Update to redis 2.6.7

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.15-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jul 08 2012 Silas Sewell <silas@sewell.org> - 2.4.15-2
- Remove TODO from docs

* Sun Jul 08 2012 Silas Sewell <silas@sewell.org> - 2.4.15-1
- Update to redis 2.4.15

* Sat May 19 2012 Silas Sewell <silas@sewell.org> - 2.4.13-1
- Update to redis 2.4.13

* Sat Mar 31 2012 Silas Sewell <silas@sewell.org> - 2.4.10-1
- Update to redis 2.4.10

* Fri Feb 24 2012 Silas Sewell <silas@sewell.org> - 2.4.8-1
- Update to redis 2.4.8

* Sat Feb 04 2012 Silas Sewell <silas@sewell.org> - 2.4.7-1
- Update to redis 2.4.7

* Wed Feb 01 2012 Fabian Deutsch <fabiand@fedoraproject.org> - 2.4.6-4
- Fixed a typo in the spec

* Tue Jan 31 2012 Fabian Deutsch <fabiand@fedoraproject.org> - 2.4.6-3
- Fix .service file, to match config (Type=simple).

* Tue Jan 31 2012 Fabian Deutsch <fabiand@fedoraproject.org> - 2.4.6-2
- Fix .service file, credits go to Timon.

* Thu Jan 12 2012 Fabian Deutsch <fabiand@fedoraproject.org> - 2.4.6-1
- Update to 2.4.6
- systemd unit file added
- Compiler flags changed to compile 2.4.6
- Remove doc/ and Changelog

* Sun Jul 24 2011 Silas Sewell <silas@sewell.org> - 2.2.12-1
- Update to redis 2.2.12

* Fri May 06 2011 Dan Horák <dan[at]danny.cz> - 2.2.5-2
- google-perftools exists only on selected architectures

* Sat Apr 23 2011 Silas Sewell <silas@sewell.ch> - 2.2.5-1
- Update to redis 2.2.5

* Sat Mar 26 2011 Silas Sewell <silas@sewell.ch> - 2.2.2-1
- Update to redis 2.2.2

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Dec 19 2010 Silas Sewell <silas@sewell.ch> - 2.0.4-1
- Update to redis 2.0.4

* Tue Oct 19 2010 Silas Sewell <silas@sewell.ch> - 2.0.3-1
- Update to redis 2.0.3

* Fri Oct 08 2010 Silas Sewell <silas@sewell.ch> - 2.0.2-1
- Update to redis 2.0.2
- Disable checks section for el5

* Sat Sep 11 2010 Silas Sewell <silas@sewell.ch> - 2.0.1-1
- Update to redis 2.0.1

* Sat Sep 04 2010 Silas Sewell <silas@sewell.ch> - 2.0.0-1
- Update to redis 2.0.0

* Thu Sep 02 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-3
- Add Fedora build flags
- Send all scriplet output to /dev/null
- Remove debugging flags
- Add redis.conf check to init script

* Mon Aug 16 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-2
- Don't compress man pages
- Use patch to fix redis.conf

* Tue Jul 06 2010 Silas Sewell <silas@sewell.ch> - 1.2.6-1
- Initial package

